@@ -7,7 +7,10 @@ class VideoRetriever(object):
         self.url = url
         self.bitrate = int(bitrate)
         self.kwargs = kwargs
-        self.http = HTTP()
+        self.http = HTTP(options)
+
+    def __repr__(self):
+        return "<Video(fetcher=%s, bitrate=%s>" % (self.__class__.__name__, self.bitrate)
 
     def name(self):
         pass
