@@ -45,8 +45,8 @@ def _get_full_url(url, srcurl):
 def hlsparse(options, res, url):
     streams = {}
 
-    if res.status_code == 403:
-        streams[0] = ServiceError("Can't read HLS playlist. permission denied")
+    if res.status_code == 403 or res.status_code == 404:
+        streams[0] = ServiceError("Can't read HLS playlist.")
         return streams
     files = (parsem3u(res.text))[1]
 
