@@ -9,7 +9,7 @@ import io
 import platform
 from datetime import timedelta
 
-from svtplay_dl.utils import is_py3, is_py2, filenamify, decode_html_entities, ensure_unicode
+from svtplay_dl.utils import is_py2, filenamify, decode_html_entities, ensure_unicode
 from svtplay_dl.utils.terminal import get_terminal_size
 from svtplay_dl.log import log
 
@@ -142,10 +142,10 @@ def filename(stream):
 
 
 def output(options, extention="mp4", openfd=True, mode="wb", **kwargs):
-    if is_py3:
-        file_d = io.IOBase
-    else:
+    if is_py2:
         file_d = file
+    else:
+        file_d = io.IOBase
 
     if options.output != "-":
         ext = re.search(r"(\.\w{2,3})$", options.output)
@@ -170,10 +170,10 @@ def output(options, extention="mp4", openfd=True, mode="wb", **kwargs):
             file_d = open(options.output, mode, **kwargs)
     else:
         if openfd:
-            if is_py3:
-                file_d = sys.stdout.buffer
-            else:
+            if is_py2:
                 file_d = sys.stdout
+            else:
+                file_d = sys.stdout.buffer
 
     return file_d
 
