@@ -1,5 +1,5 @@
-# ex:ts=4:sw=4:sts=4:et
-# -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
+# -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil: coding: utf-8 -*-
+# ex:ts=4:sw=4:sts=4:et:fenc=utf-8
 from __future__ import absolute_import
 import sys
 import logging
@@ -17,7 +17,7 @@ is_py3 = (sys.version_info[0] == 3)
 is_py2_old = (sys.version_info < (2, 7))
 
 # Used for UA spoofing in get_http_data()
-FIREFOX_UA = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3'
+FIREFOX_UA = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2454.101 Safari/537.3'
 
 log = logging.getLogger('svtplay_dl')
 progress_stream = sys.stderr
@@ -30,8 +30,12 @@ except ImportError:
 
 
 class HTTP(Session):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, options, *args, **kwargs):
         Session.__init__(self, *args, **kwargs)
+        self.verify = options.ssl_verify
+        if options.http_headers:
+            self.headers.update(self.split_header(options.http_headers))
+        self.headers.update({"User-Agent": FIREFOX_UA})
 
     def check_redirect(self, url):
         return self.get(url, stream=True).url
@@ -39,13 +43,16 @@ class HTTP(Session):
     def request(self, method, url, *args, **kwargs):
         headers = kwargs.pop("headers", None)
         if headers:
-            headers["User-Agent"] = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2454.101 Safari/537.3"
-        else:
-            headers = {"User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/45.0.2454.101 Safari/537.3"}
+            for i in headers.keys():
+                self.headers[i] = headers[i]
+
         log.debug("HTTP getting %r", url)
-        res = Session.request(self, method, url, headers=headers, *args, **kwargs)
+        res = Session.request(self, method, url, verify=self.verify, *args, **kwargs)
         return res
 
+    def split_header(self, headers):
+        return dict(x.split('=') for x in headers.split(';'))
+
 
 def sort_quality(data):
     data = sorted(data, key=lambda x: (x.bitrate, x.name()), reverse=True)
@@ -62,6 +69,19 @@ def list_quality(videos):
         log.info("%s\t%s" % (i[0], i[1].upper()))
 
 
+def prio_streams(options, streams, selected):
+    prio = options.stream_prio
+    if prio is None:
+        prio = ["hls","hds", "http", "rtmp"]
+    if isinstance(prio, str):
+        prio = prio.split(",")
+    lstreams = []
+    for i in streams:
+        if int(i.bitrate) == selected:
+            lstreams.append(i)
+    return [x for (y, x) in sorted(zip(prio, lstreams))]
+
+
 def select_quality(options, streams):
     available = sorted(int(x.bitrate) for x in streams)
     try:
@@ -93,10 +113,7 @@ def select_quality(options, streams):
         log.error("Can't find that quality. Try one of: %s (or try --flexible-quality)", quality)
 
         sys.exit(4)
-    for i in streams:
-        if int(i.bitrate) == selected:
-            stream = i
-    return stream
+    return prio_streams(options, streams, selected)[0]
 
 
 def ensure_unicode(s):
@@ -124,26 +141,23 @@ def decode_html_entities(s):
 
 def filenamify(title):
     """
-    Convert a string to something suitable as a file name.
-
-        >>> print(filenamify(u'Matlagning del 1 av 10 - R\xe4ksm\xf6rg\xe5s | SVT Play'))
-        matlagning.del.1.av.10.-.raksmorgas.svt.play
+    Convert a string to something suitable as a file name. E.g.
 
+     Matlagning del 1 av 10 - Räksmörgås | SVT Play
+       ->  matlagning.del.1.av.10.-.raksmorgas.svt.play
     """
     # ensure it is unicode
     title = ensure_unicode(title)
 
-    # NFD decomposes chars into base char and diacritical mark, which means that we will get base char when we strip out non-ascii.
+    # NFD decomposes chars into base char and diacritical mark, which
+    # means that we will get base char when we strip out non-ascii.
     title = unicodedata.normalize('NFD', title)
 
+    # Convert to lowercase
     # Drop any non ascii letters/digits
-    title = re.sub(r'[^a-zA-Z0-9 -.]', '', title)
-    # Remove " and '
-    title = re.sub('[\"\']', '', title)
     # Drop any leading/trailing whitespace that may have appeared
-    title = title.strip()
-    # Lowercase
-    title = title.lower()
+    title = re.sub(r'[^a-z0-9 .-]', '', title.lower().strip())
+
     # Replace whitespace with dot
     title = re.sub(r'\s+', '.', title)
 
